@@ -29,9 +29,12 @@
 void parse_args(int argc, char **argv);
 void init(int argc, char **argv);
 void quit(struct font_s *font);
+
 extern char *font_file_name;
 extern FILE *font_file;
 extern char *file_data;
+extern int startup_rawfont_width;
+extern int startup_rawfont_height;
 
 /* status.c */
 void status_error(char *msg);
