@@ -1,5 +1,5 @@
 /* 
- *    Copyright 2015, 2016, 2017, 2018 (c) Mohammed Isam Mohammed [mohammed_isam1984@yahoo.com]
+ *    Copyright 2015, 2016, 2017, 2018, 2024 (c) Mohammed Isam Mohammed [mohammed_isam1984@yahoo.com]
  * 
  *    file: main.c
  *    This file is part of fontopia.
@@ -18,6 +18,8 @@
  *    along with fontopia.  If not, see <http://www.gnu.org/licenses/>.
  */    
 
+#include <locale.h>
+#include <ncurses.h>
 #include "defs.h"
 #include "view.h"
 #include "glyph.h"
@@ -25,15 +27,15 @@
 #include "modules/cp.h"
 #include "menu.h"
 
-extern int fcloseall (void);	/* stdio.h */
+extern int fcloseall (void);    /* stdio.h */
 
-char *readme_file = "/usr/share/doc/fontopia/README";
-char *keys_file   = "/usr/share/doc/fontopia/READMEkeys";
+//char *readme_file = "/usr/share/doc/fontopia/README";
+//char *keys_file   = "/usr/share/doc/fontopia/READMEkeys";
 
-extern char *fontopia_ver;	/* args.c */
+extern char *fontopia_ver;    /* args.c */
 char *about_str = "Fontopia for GNU/Linux, "
-	          "Version 0.0 \n"
-	          "By Mohammed Isam, 2015, 2016, 2017, 2018";
+              "Version 0.0  \n"
+              "By Mohammed Isam, 2015, 2016, 2017, 2018, 2024";
 /* global flag to indicate if we need to exit */
 int end = 0;
 
@@ -53,13 +55,12 @@ int big_endian;
  */
 void exit_gracefully()
 {
-    restoreTerminal(); 
     setScreenColors(WHITE, BGDEFAULT);
     clearScreen(); 
     setScreenColors(WHITE, BGDEFAULT);
-    fprintf(stdout, "\x1b[24m");
+    reset_attribs();
     showCursor();
-    fflush(stdout);
+    restoreTerminal(); 
     fcloseall();
     exit(0);
 }
@@ -74,37 +75,46 @@ void sighandler(int signo)
 {
     if(signo == SIGTSTP) 
     { //CTRL-Z pressed
-        int i = msgBox("Are you sure you want to exit?", YES | NO, CONFIRM);
-        if(i == YES) 
-        { 	//exit gracefully
+        int i = msgBox("Are you sure you want to exit?", 
+                        BUTTON_YES | BUTTON_NO, CONFIRM);
+
+        if(i == BUTTON_YES) 
+        {     //exit gracefully
             exit_gracefully();
-        } 
+        }
         else 
         {
             //refresh_view();
-        }//end inner if
+        }
     }
     else 
     {
         end = 1;
-    }//end outer if
+    }
 }//end sighandler
 
 
 int main(int argc, char **argv)
 {
-    init(argc, argv);
     struct font_s *font;
+
+    setlocale(LC_ALL, "");
+    init(argc, argv);
+
     /* clear the screen */
     clearScreen();
+
     if(font_file_name)
     {
         if(!(font = load_font_file(font_file_name)))
         {
-            fflush(stdout);
-            int res = msgBox("Continue with a new empty font?", YES|NO, ERROR);
-            if(res == NO) exit_gracefully();
+            refresh();
+            if(msgBox("Continue with a new empty font?", 
+                        BUTTON_YES|BUTTON_NO, ERROR) == BUTTON_NO)
+                exit_gracefully();
             if(!(font = create_empty_font())) exit_gracefully();
+            if(font_file_name) free(font_file_name);
+            font_file_name = NULL;
         }
     }
     else
@@ -112,6 +122,10 @@ int main(int argc, char **argv)
         if(!(font = create_empty_font())) exit_gracefully();
     }
     //refresh_view_status_msg(font_file_name, font);
+
+    // we don't need those after start up
+    startup_rawfont_width = 0;
+    startup_rawfont_height = 0;
   
     /*
      * TODO: We should use this information to add
@@ -123,24 +137,40 @@ int main(int argc, char **argv)
     int i;
     int ch = 0;
     char *abt;
+
     while(!end) 
-    {	//infinite program loop//
+    {    //infinite program loop//
         ch = getKey();
         //printf("%d", ch);
+
         switch(ch) 
         {
+            // CTRL-H (^H) is read as CTRL-Backspace
+            case(BACKSPACE_KEY):
+                if(CTRL)
+                {
+                    //show_readme(readme_file, NULL, 0);
+                    fontopia_show_readme(readme_text, " README ");
+                    refresh_view_status_msg(font_file_name, font);
+                }
+                break;
+
             case(UP_KEY):
                 do_up(font);
                 break;
+
             case(DOWN_KEY):
                 do_down(font);
                 break;
+
             case(LEFT_KEY):
                 do_left(font);
                 break;
+
             case(RIGHT_KEY):
                 do_right(font);
                 break;
+
             case('a'):
             case('A'):
                 abt = (char *)malloc(strlen(about_str)+1);
@@ -149,14 +179,18 @@ int main(int argc, char **argv)
                     status_error("Insufficient memory!");
                     break;
                 }
+
                 strcpy(abt, about_str);
-                for(i = 0; i < strlen(fontopia_ver); i++) abt[32+i] = fontopia_ver[i];
-                show_about(abt);
+                for(i = 0; i < (int)strlen(fontopia_ver); i++) 
+                    abt[32+i] = fontopia_ver[i];
+
+                showAbout(abt);
                 free(abt);
                 refresh_left_window(font);
                 refresh_right_window(font);
                 hideCursor();
                 break;
+
             case('b'):
             case('B'):
                 if(!CTRL)
@@ -168,6 +202,7 @@ int main(int argc, char **argv)
                 if(buffer_mode_on) status_msg("Buffering is ON");
                 else               status_msg("Buffering is OFF");
                 break;
+
             case('c'):
             case('C'):
                 if(CTRL)
@@ -181,6 +216,7 @@ int main(int argc, char **argv)
                     refresh_left_window(font);
                 }
                 break;
+
             case('d'):
             case('D'):
                 if(CTRL)
@@ -197,16 +233,19 @@ int main(int argc, char **argv)
                     refresh_left_window(font);
                 }
                 break;
+
             case('e'):
             case('E'):
                 export_unitab(font);
                 break;
+
             case('g'):
             case('G'):
                 show_glyph_info(font);
                 refresh_left_window(font);
                 refresh_right_window(font);
                 break;
+
             case('h'):
             case('H'):
                 if(CTRL)
@@ -221,6 +260,7 @@ int main(int argc, char **argv)
                     refresh_left_window(font);
                 }
                 break;
+
             case('i'):
             case('I'):
                 import_unitab(font);
@@ -228,6 +268,7 @@ int main(int argc, char **argv)
                 refresh_right_window(font);
                 hideCursor();
                 break;
+
             case('j'):
             case('J'):
                 if(!CTRL)
@@ -237,12 +278,14 @@ int main(int argc, char **argv)
                      */
                 }
                 break;
+
             case('k'):
             case('K'):
                 //show_readme(keys_file, " KEYS ", 0);
                 fontopia_show_readme(keys_text, " KEYS ");
                 refresh_view_status_msg(font_file_name, font);
                 break;
+
             case('l'):
             case('L'):
                 if(!CTRL)
@@ -250,6 +293,7 @@ int main(int argc, char **argv)
                     draw_shape(font, 'l');
                 }
                 break;
+
             case('m'):
             case('M'):
                 show_font_metrics(font);
@@ -257,6 +301,7 @@ int main(int argc, char **argv)
                 refresh_right_window(font);
                 hideCursor();
                 break;
+
             case('n'):
             case('N'):
                 if(CTRL)
@@ -281,6 +326,7 @@ int main(int argc, char **argv)
                      */
                 }
                 break;
+
             case('o'):
             case('O'):
                 if(CTRL)
@@ -299,6 +345,7 @@ int main(int argc, char **argv)
                     show_ext_glyph_operations(font);
                 }
                 break;
+
             case('p'):
             case('P'):
                 if(font->version == VER_CP)
@@ -313,11 +360,13 @@ int main(int argc, char **argv)
                 refresh_right_window(font);
                 hideCursor();
                 break;
+
             case('q'):
             case('Q'):
                 //if(CTRL) quit(font);
                 quit(font);
                 break;
+
             case('r'):
             case('R'):
                 if(!CTRL)
@@ -337,13 +386,14 @@ int main(int argc, char **argv)
                 refresh_right_window(font);
                 hideCursor();
                 break;
+
             case('s'):
             case('S'):
                 if(CTRL)
                 {
-                    if(SHIFT)	/* force saving with new file name */
+                    if(SHIFT)    /* force saving with new file name */
                          font = save_font_file(font, 1);
-                    else font = save_font_file(font, 0);	/* save with -probably- old name */
+                    else font = save_font_file(font, 0);    /* save with -probably- old name */
                     refresh_left_window(font);
                     refresh_right_window(font);
                     hideCursor();
@@ -354,6 +404,7 @@ int main(int argc, char **argv)
                     refresh_left_window(font);
                 }
                 break;
+
             case('t'):
             case('T'):
                 if(!CTRL)
@@ -363,6 +414,7 @@ int main(int argc, char **argv)
                      */
                 }
                 break;
+
             case('u'):
             case('U'):
                 open_unicode_table(font);
@@ -370,6 +422,7 @@ int main(int argc, char **argv)
                 refresh_right_window(font);
                 hideCursor();
                 break;
+
             case('v'):
             case('V'):
                 if(CTRL)
@@ -390,10 +443,13 @@ int main(int argc, char **argv)
                     refresh_left_window(font);
                 }
                 break;
+
             case('w'):
             case('W'):
-                if(!CTRL && !ALT) export_glyphs(font);
+                if(CTRL) export_glyphs(font, 1);    // export as C source file
+                else if(!ALT) export_glyphs(font, 0); // export as plain text
                 break;
+
             case('x'):
             case('X'):
                 if(CTRL)
@@ -404,9 +460,11 @@ int main(int argc, char **argv)
                     break;
                 }
                 zoom_out(font); break;
+
             case('z'):
             case('Z'):
                 zoom_in(font); break;
+
             case(SPACE_KEY):
             case(ENTER_KEY):
                 if(active_window == &right_window)
@@ -419,10 +477,12 @@ int main(int argc, char **argv)
                 }
                 refresh_left_window(font);
                 break;
+
             case(TAB_KEY):
                 active_window = active_window->next;
                 refresh_left_window(font);
                 break;
+
             case(ESC_KEY):
                 if(active_window == &left_window)
                 {
@@ -430,11 +490,14 @@ int main(int argc, char **argv)
                     refresh_left_window(font);
                 }
                 break;
+
             default:
                 if(ch >= '1' && ch <= '9') 
                     cp_change_active_font(font, ch-'0');
                 break;
         }
     }
+
     exit(0);
 }
+
