@@ -63,7 +63,7 @@ struct cp_header
 
 struct font_s *cp_create_empty_font();
 struct font_s *cp_load_font_file(char *file_name);
-struct font_s *cp_load_font(unsigned char *file_data, long file_size);
+struct font_s *cp_load_font(char *file_name, unsigned char *file_data, long file_size);
 int cp_write_to_file(FILE *file, struct font_s *font);
 void cp_change_active_font(struct font_s *font, char cp_index);
 void cp_handle_hw_change(struct font_s *font, char *newdata, long new_datasize);
@@ -74,7 +74,7 @@ void cp_kill_unitab(struct font_s *font);
 void cp_convert_to_psf(struct font_s *font);
 void cp_change_codepage(struct font_s *font);
 void cp_init_module();
-void cp_handle_unicode_table_change(struct font_s *font, char old_has_unicode_table);
+void cp_handle_unicode_table_change(struct font_s *font);
 
 //extern char *cp_files_prefix;
 extern int cp_files_count;
