@@ -28,7 +28,7 @@
 
 struct font_s *raw_create_empty_font();
 struct font_s *raw_load_font_file(char *file_name);
-struct font_s *raw_load_font(unsigned char *file_data, long file_size);
+struct font_s *raw_load_font(char *file_name, unsigned char *file_data, long file_size);
 int raw_write_to_file(FILE *file, struct font_s *font);
 void raw_handle_hw_change(struct font_s *font, char *newdata, long new_datasize);
 void raw_handle_version_change(struct font_s *font, char old_version);
@@ -39,5 +39,6 @@ void raw_convert_to_psf(struct font_s *font);
 void raw_shrink_glyphs(struct font_s *font, int old_length);
 void raw_expand_glyphs(struct font_s *font, int old_length, int option);
 void raw_init_module();
+int raw_acceptable_filesize(long file_size);
 
 #endif
