@@ -1,5 +1,5 @@
 /* 
- *    Copyright 2015, 2016, 2017, 2018 (c) Mohammed Isam Mohammed [mohammed_isam1984@yahoo.com]
+ *    Copyright 2015, 2016, 2017, 2018, 2024 (c) Mohammed Isam Mohammed [mohammed_isam1984@yahoo.com]
  * 
  *    file: status.c
  *    This file is part of fontopia.
@@ -18,52 +18,58 @@
  *    along with fontopia.  If not, see <http://www.gnu.org/licenses/>.
  */    
 
+#include <ncurses.h>
 #include "defs.h"
 
 void _do_status(char *msg, int STATUS)
 {
-  int row = SCREEN_H-1;
-  int col = 2;
-  int w = SCREEN_W-2;
-  int i;
-  int len;
-  if(!msg) len = 0;
-  else len = strlen(msg);
+    int row = SCREEN_H-1;
+    int col = 2;
+    int w = SCREEN_W-2;
+    int i;
+    int len;
 
-  switch(STATUS)
-  {
-    case STATUS_ERROR:
-      setScreenColors(WHITE, BGRED); break;
-    case STATUS_REGULAR:
-    default:
-      setScreenColors(BLACK, BGWHITE); break;
-  }
+    if(!msg) len = 0;
+    else len = strlen(msg);
+
+    switch(STATUS)
+    {
+        case STATUS_ERROR:
+            setScreenColors(WHITE, BGRED); break;
+
+        case STATUS_REGULAR:
+        default:
+            setScreenColors(BLACK, BGWHITE); break;
+    }
   
-  locate(row, col);
-  if(len > w)
-  {
-    for(i = 0; i < w; i++) putchar(msg[i]);
-  }
-  else
-  {
-    if(msg) printf("%s", msg);
-    if(w-len) printf("%*s", w-len, " ");
-  }
-  hideCursor();
-  fflush(stdout);
+    locate(row, col);
+
+    if(len > w)
+    {
+        for(i = 0; i < w; i++) putchar(msg[i]);
+    }
+    else
+    {
+        if(msg) printw("%s", msg);
+        if(w-len) printw("%*s", w-len, " ");
+    }
+
+    hideCursor();
+    refresh();
 }
 
 void status_error(char *msg)
 {
-  _do_status(msg, STATUS_ERROR);
+    _do_status(msg, STATUS_ERROR);
 }
 
 void status_msg(char *msg)
 {
-  _do_status(msg, STATUS_REGULAR);
+    _do_status(msg, STATUS_REGULAR);
 }
 
 void status_clear()
 {
-  _do_status(" ", STATUS_REGULAR);
+    _do_status(" ", STATUS_REGULAR);
 }
+
